package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.CompanyReview;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.CompanyReviewMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 省公司评审
 * @author: 王强
 * @create: 2022-10-24 16:00
 **/
@Service
@Transactional(readOnly = true)
public class CompanyReviewService extends CrudService<CompanyReviewMapper, CompanyReview> {

    @Autowired
    private CompanyReviewMapper dao;

    public CompanyReview getByProId(String proId){
           return dao.getByProId(proId);
    }

    /**
     * 根据项目储备编号删除省公司评审信息
     * @param projectReserveId
     */
    @Transactional(readOnly = false)
    public void deleteByProjectReserveId(String projectReserveId){
        dao.deleteActivityByProId(projectReserveId);
    }

    /**
     * 根据项目储备id查询项目信息
     * @param companyReview
     * @return
     */
    public CompanyReview queryByProjectReserveId(CompanyReview companyReview){
        return dao.queryByProjectReserveId(companyReview);
    }

    /**
     * 根据 项目储备编号删除对应的流程信息
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteActivityByProId(String proId){
        dao.deleteActivityByProId(proId);
    }

    public Page<CompanyReview> findPage(Page<CompanyReview> page, CompanyReview companyReview) {
        Page<CompanyReview> pageList = super.findPage(page, companyReview);
        return pageList;
    }

    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param companyReviews
     * @return
     */
    public Map<String,List<CompanyReview>> getExistProjectList(List<CompanyReview> companyReviews){
        Map<String,List<CompanyReview>> map = new HashMap();
        List<CompanyReview> existReserveManagementList = new ArrayList<>();
        Iterator<CompanyReview> iterator = companyReviews.iterator();
        while (iterator.hasNext()) {
            CompanyReview rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            CompanyReview reserveManag = dao.queryByProjectReserveId(rm);

            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }
        }
        map.put("without",companyReviews);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param companyReviewList
     */
    @Transactional(readOnly = false)
    public void insertList(List<CompanyReview> companyReviewList){
        dao.insertList(companyReviewList);
    }

    /**
     * 修改方法
     * @param companyReview
     */
    @Transactional(readOnly = false)
    public void update(CompanyReview companyReview) {

        super.save(companyReview);
    }

    public List<CompanyReview> exportFindList(CompanyReview companyReview) {
        List<CompanyReview> pageList = dao.exportFindList(companyReview);
        return pageList;
    }
}
