package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveSummary;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.mapper.SummaryStatisticMapper;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 储备项目交底信息汇总统计 service
 * @author: 王强
 * @create: 2022-07-27 11:05
 **/
@Service
@Transactional(readOnly = true)
public class SummaryStatisticService extends CrudService<SummaryStatisticMapper, ReserveSummary> {

    @Autowired
    private SummaryStatisticMapper dao;

    public ReserveSummary getByProId(String proId){
        return dao.getByProId(proId);
    }

    /**
     * 根据项目储备编号删除交底信息汇总信息
     * @param projectReserveId
     */
    @Transactional(readOnly = false)
    public void deleteByProjectReserveId(String projectReserveId){
        dao.deleteByProjectReserveId(projectReserveId);
    }

    /**
     * 查出所有的  项目编码 及 是否纳入储备字段
     * @return
     */
    public List<ReserveSummary> getAllCode(){
        return dao.getAllCode();
    }

    /**
     * 获取所有的 项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 从基本数据表中查出所有的 项目储备编号
     * @return
     */
    public List<String> getAllProId2(){
        return dao.getAllProId2();
    }

    /**
     * 根据项目储备id查询项目信息
     * @param reserveManagement
     * @return
     */
    public ReserveSummary queryByProjectReserveId(ReserveSummary reserveManagement){
        return dao.queryByProjectReserveId(reserveManagement);
    }

    /**
     * 查询已有的参数数据 并分类返回已存在数据和未存在数据
     * @param reserveManagement
     * @return
     */
    public Map<String, List<ReserveSummary>> getExistProjectList(List<ReserveSummary> reserveManagement){
        Map<String,List<ReserveSummary>> map = new HashMap();
        List<ReserveSummary> existReserveManagementList = new ArrayList<>();
        Iterator<ReserveSummary> iterator = reserveManagement.iterator();
        while (iterator.hasNext()) {
            ReserveSummary rm = iterator.next();
            //对数据进行处理
            rm.preInsert();
            ReserveSummary reserveManag = dao.queryByProjectReserveId(rm);
            //数据库中已含有的数据在list中删除并创建一个list加入 区分为已存在数据
            if (null != reserveManag) {
                rm.setId(reserveManag.getId());
                existReserveManagementList.add(rm);
                iterator.remove();//使用迭代器删除已存在的数据
            }

        }
        map.put("without",reserveManagement);
        map.put("exist",existReserveManagementList);
        return map;
    }

    /**
     * 批量添加数据
     * @param reserveManagementList
     */
    @Transactional(readOnly = false)
    public void insertList(List<ReserveSummary> reserveManagementList){

        dao.insertList(reserveManagementList);
    }

    /**
     * 专职修改方法
     * @param reserveManagement
     */
    @Transactional(readOnly = false)
    public void update(ReserveSummary reserveManagement) {

        super.save(reserveManagement);
    }

    public Page<ReserveSummary> findPage(Page<ReserveSummary> page, ReserveSummary reserveManagement) {
        Page<ReserveSummary> pageList = super.findPage(page, reserveManagement);
        return pageList;
    }

    public List<ReserveSummary> exportFindList( ReserveSummary reserveManagement) {
        List<ReserveSummary> pageList = dao.exportFindList(reserveManagement);
        return pageList;
    }

    /**
     * 新增方法
     * @param entity
     */
    @Transactional(readOnly = false)
    public void save(ReserveSummary entity) {
        //查询数据表中是否含有同项目储备编号的数据 若有则进行修改 没有则新增
        //根据项目储备编号 查询数据
        if (entity.getIsNewRecord()){
            entity.preInsert();
            mapper.insert(entity);
        }else{
            entity.preUpdate();
            mapper.update(entity);
        }
    }

    @Transactional(readOnly = false)
    public void insert(ReserveSummary entity) {
        mapper.insert(entity);
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }
}
