package com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.ReserveSafety;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveSafeDisclosureService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 储备项目安全交底信息表 controller
 * @author: 王强
 * @create: 2022-07-25 08:33
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/reserveSafeDisclosure")
public class ReserveSafeDisclosureController extends BaseController {

    /*@Autowired
    private ReserveElectricityWorkService workService;*/

    @Autowired
    private ReserveSafeDisclosureService safeService;


    @ModelAttribute
    public ReserveSafety get(@RequestParam(required = false) String id) {
        ReserveSafety entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = safeService.get(id);
        }
        if (entity == null) {
            entity = new ReserveSafety();
        }
        return entity;
    }

    /**
     * 项目储备信息列表页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:reserveSafeDisclosure:list")
    @RequestMapping(value = "skipList")
    public String skipList(ReserveSafety reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/reserveSafeDisclosure/reserveManagementInformation";
    }



    /**
     * 项目储备信息数据列表
     * @param reserveManagement
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveSafeDisclosure:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(ReserveSafety reserveManagement, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<ReserveSafety> page = safeService.findPage(new Page<ReserveSafety>(request, response), reserveManagement);
        List<ReserveSafety> list = page.getList();
        List<ReserveSafety> safetyList = new ArrayList<>();
        for (ReserveSafety safety : list){
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = safeService.getByProjectReserveId(safety.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            List<History> histories = safeService.getHistoryByExecuteId(procInsId);
            //当size>0时待办有历史流程，
            if (histories.size()>0){
                //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                String name = safeService.getByExecuteId(procInsId);
                //设置项目进度
                safety.setReserveProgress(name);
            }else {
                safety.setReserveProgress("");
            }
            safetyList.add(safety);
        }
        return getBootstrapData(page);
    }


    /**
     * 查看表单页面
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveSafeDisclosure:view"},logical= Logical.OR)
    @RequestMapping(value = "view")
    public String view(ReserveSafety reserveManagement, Model model) {
        model.addAttribute("reserveManagement", reserveManagement);
        return "modules/cg/reservemanagementcenter/reserveManage/reserveSafeDisclosure/reserveManagementView";
    }


    /**
     * 专职人员保存表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveSafeDisclosure:add"},logical=Logical.OR)
    @RequestMapping(value = "save")
    public AjaxJson save(ReserveSafety reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //新增或编辑表单保存
        safeService.save(reserveManagement);//保存
        j.setSuccess(true);
        j.setMsg("保存储备项目基本信息成功");
        return j;
    }


    /**
     * 专职人员修改表单
     * @param reserveManagement
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveSafeDisclosure:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(ReserveSafety reserveManagement){
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(reserveManagement);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;
        }
        //根据项目储备编号查是否有改数据
        ReserveSafety safety = safeService.getByReserveId(reserveManagement.getProjectReserveId());
        if (null == safety){
            safety = new ReserveSafety(
                    reserveManagement.getProjectReserveId(),reserveManagement.getTransmissionWork(),
                    reserveManagement.getWorkDescribe(),reserveManagement.getTransmissionErection(),
                    reserveManagement.getErecteDescribe(),reserveManagement.getTransmissionCommonTrench(),
                    reserveManagement.getTrenchDescribe(),reserveManagement.getMediumVoltageWork(),
                    reserveManagement.getVoltageWorkDescribe(),reserveManagement.getConfineSpaceWork(),
                    reserveManagement.getSpaceDescribe(),reserveManagement.getSubStationCableBonding(),
                    reserveManagement.getCableDescribe(),reserveManagement.getRoadRailwaysAndWaterwaysWork(),
                    reserveManagement.getWaterDescribe(),reserveManagement.getHotWork(),
                    reserveManagement.getHotWorkDescribe(),reserveManagement.getBlackoutLineFour(),
                    reserveManagement.getLineFourDescribe(),reserveManagement.getLineLoadRedirectionThree(),
                    reserveManagement.getThreeRedirectDescribe(),reserveManagement.getLargeScaleMultiTeamWork(),
                    reserveManagement.getTeamWorkDescribe(),reserveManagement.getPrepareThreeMeasures(),
                    reserveManagement.getMeasureDescribe(),reserveManagement.getJobRiskLevelPrediction()
            );
            safeService.save(safety);
        }else {
            safety.setTransmissionWork(reserveManagement.getTransmissionWork());
            safety.setWorkDescribe(reserveManagement.getWorkDescribe());
            safety.setTransmissionErection(reserveManagement.getTransmissionErection());
            safety.setErecteDescribe(reserveManagement.getErecteDescribe());
            safety.setTransmissionCommonTrench(reserveManagement.getTransmissionCommonTrench());
            safety.setTrenchDescribe(reserveManagement.getTrenchDescribe());
            safety.setMediumVoltageWork(reserveManagement.getMediumVoltageWork());
            safety.setVoltageWorkDescribe(reserveManagement.getVoltageWorkDescribe());
            safety.setConfineSpaceWork(reserveManagement.getConfineSpaceWork());
            safety.setSpaceDescribe(reserveManagement.getSpaceDescribe());
            safety.setSubStationCableBonding(reserveManagement.getSubStationCableBonding());
            safety.setCableDescribe(reserveManagement.getCableDescribe());
            safety.setRoadRailwaysAndWaterwaysWork(reserveManagement.getRoadRailwaysAndWaterwaysWork());
            safety.setWaterDescribe(reserveManagement.getWaterDescribe());
            safety.setHotWork(reserveManagement.getHotWork());
            safety.setHotWorkDescribe(reserveManagement.getHotWorkDescribe());
            safety.setBlackoutLineFour(reserveManagement.getBlackoutLineFour());
            safety.setLineFourDescribe(reserveManagement.getLineFourDescribe());
            safety.setLineLoadRedirectionThree(reserveManagement.getLineLoadRedirectionThree());
            safety.setThreeRedirectDescribe(reserveManagement.getThreeRedirectDescribe());
            safety.setLargeScaleMultiTeamWork(reserveManagement.getLargeScaleMultiTeamWork());
            safety.setTeamWorkDescribe(reserveManagement.getTeamWorkDescribe());
            safety.setPrepareThreeMeasures(reserveManagement.getPrepareThreeMeasures());
            safety.setMeasureDescribe(reserveManagement.getMeasureDescribe());
            safety.setJobRiskLevelPrediction(reserveManagement.getJobRiskLevelPrediction());

            //新增或编辑表单保存
            safeService.update(safety);
        }

        j.setSuccess(true);
        j.setMsg("修改储备项目基本信息成功");
        return j;
    }

    /**
     * 导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveSafeDisclosure:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = safeService.getAllProId();

            //从基本数据表中查出所有的 项目储备编号
            List<String> proIdList2 = safeService.getAllProId2();

            //获取导入表格所有数据
            List<ReserveSafety> reserveManagementList = ReserveProcessProjectProUtil.getSafetyProjectUtil(importUtil,proIdList,proIdList2);
            //查询已有的参数数据 并分类返回已存在数据和未存在数据
            Map map = safeService.getExistProjectList(reserveManagementList);
            //未存在数据
            List<ReserveSafety> withoutList = (List<ReserveSafety>) map.get("without");
            //已存在数据
            List<ReserveSafety> existList = (List<ReserveSafety>) map.get("exist");

            //对未存在的数据进行批量导入
            if(withoutList.size()>0){
                safeService.insertList(withoutList);
            }

            //对已存在的数据进行修改
            if(existList.size()>0){
                for (ReserveSafety reserveManagement : existList) {
                    safeService.update(reserveManagement);
                }
            }
            int i = withoutList.size() + existList.size();
            j.setMsg("已成功导入" + i + "条项目储备信息记录");

        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入项目储备信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }


    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:reserveSafeDisclosure:export")
    @RequestMapping(value = "export")
    public void exportExcel(ReserveSafety reserveManagement, HttpServletRequest request, HttpServletResponse response) {
        List<ReserveSafety> list = safeService.exportFindList(reserveManagement);

        List<ReserveSafety> safetyList = new ArrayList<>();
        for (ReserveSafety safety : list){
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = safeService.getByProjectReserveId(safety.getProjectReserveId());
            //根据procInsId查出历史流程名称和时间
            List<History> histories = safeService.getHistoryByExecuteId(procInsId);
            //当size>0时待办有历史流程，
            if (histories.size()>0){
                //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
                String name = safeService.getByExecuteId(procInsId);
                //设置项目进度
                safety.setReserveProgress(name);
            }else {
                safety.setReserveProgress("");
            }
            safetyList.add(safety);
        }

        //生成序列号
        int i = 1;
        for (ReserveSafety s : safetyList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ReserveProcessProjectExportUtil util = ReserveProcessProjectExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("reserveSafety");
        util.exportSafety(response,workbook,safetyList);
    }


    /**
     * 专职人员增加，编辑表单页面
     * @param reserveManagement
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:reserveSafeDisclosure:add","cg:reservemanagementcenter:reserveSafeDisclosure:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(ReserveSafety reserveManagement, Model model) {
        //根据projectReserveId查出流程表的proc_ins_id
        String procInsId = safeService.getByProjectReserveId(reserveManagement.getProjectReserveId());
        //根据procInsId查出历史流程名称和时间
        List<History> histories = safeService.getHistoryByExecuteId(procInsId);
        //当size>0时待办有历史流程，
        if (histories.size()>0){
            //根据proc_ins_id去运行时任务节点表（act_ru_task）中查出当前流程名称
            String name = safeService.getByExecuteId(procInsId);
            //设置项目进度
            reserveManagement.setReserveProgress(name);
        }else {
            reserveManagement.setReserveProgress("");
        }
        model.addAttribute("reserveManagement", reserveManagement);
        //判断id是否为空 如果未空则为新增 否则为修改
        if(StringUtils.isBlank(reserveManagement.getId())){
            return "modules/cg/reservemanagementcenter/reserveManage/reserveSafeDisclosure/reserveManagementForm";
        }
        return "modules/cg/reservemanagementcenter/reserveManage/reserveSafeDisclosure/reserveManagementModifyByzz";
    }
}
