package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.BudgetStats;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.mapper.BudgetStatsMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

/**
 * 储备项目概预算统计表
 * @author: 王强
 * @create: 2022-08-16 13:43
 **/
@Service
@Transactional(readOnly = true)
public class BudgetStatsService extends CrudService<BudgetStatsMapper, BudgetStats> {

    @Autowired
    private BudgetStatsMapper dao;

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    /**
     * 获取省公司评审表的  更新时间
     * @param proId
     * @return
     */
    public Date getTimeByProID(String proId){
        return dao.getTimeByProID(proId);
    }

    @Transactional(readOnly = false)
    public void insertList(@Param("list") List<BudgetStats> list){
        List<BudgetStats> statsList = dao.exportFindList(null);
        for(BudgetStats budgetStats : list){
            statsList.forEach(sta->{
                if (sta.getProjectReserveId().equals(budgetStats.getProjectReserveId())){
                    dao.deleteByProId(sta.getProjectReserveId());
                }
            });
            budgetStats.preInsert();
        }

        dao.insertList(list);
    }

    public Page<BudgetStats> findPage(Page<BudgetStats> page, BudgetStats budgetStats) {
        Page<BudgetStats> pageList = super.findPage(page, budgetStats);
        return pageList;
    }


    @Transactional(readOnly = false)
    public void update(BudgetStats budgetStats) {

        super.save(budgetStats);
    }

    /**
     * 根据项目储备编号删除方法
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteByProId(String proId) {
        dao.deleteByProId(proId);
    }

    public int selectCount(String projectReserveId){
        return dao.selectCount(projectReserveId);
    }

    public List<BudgetStats> exportFindList( BudgetStats budgetStats) {
        List<BudgetStats> pageList = dao.exportFindList(budgetStats);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId){
        return dao.getByProjectReserveId(projectReserveId);
    }

    public String getByExecuteId(String executeId){
        return dao.getByExecuteId(executeId);
    }

    public List<History> getHistoryByExecuteId(String executeId){
        return dao.getHistoryByExecuteId(executeId);
    }

    public List<History> getHistoryByActName(String executeId){
        return dao.getHistoryByActName(executeId);
    }

    public History getHistoryByTime(String time,String executeId){
        return dao.getHistoryByTime(time, executeId);
    }

    //获取储备进度列值的公共方法
    public String getReserveProgress(String proId){
        //根据projectReserveId查出流程表的proc_ins_id
        String procInsId = mapper.getByProjectReserveId(proId);
        //根据procInsId查出历史流程名称和时间
        List<History> histories = mapper.getHistoryByExecuteId(procInsId);

        String val = "";

        //当size>0时待办有历史流程，
        if (histories.size()>0){

            //计数器
            int sjCount = 0;
            for (int k=0;k<histories.size();k++){
                if (histories.get(k).getName().equals("设计单位上传文件")){
                    ++sjCount;
                    if (sjCount==1 & StringUtils.isEmpty(histories.get(0).getEndTime())){
                        val = "设计委托发起";
                    }else if (sjCount>1 & StringUtils.isEmpty(histories.get(0).getEndTime())){
                        val = "设计委托修改中";
                    }
                }

                if (sjCount ==1 & (histories.get(0).getName().equals("项目经理审图") ||
                        histories.get(0).getName().equals("联合审图") ||
                        histories.get(0).getName().equals("技经人员审预算")) &
                        StringUtils.isEmpty(histories.get(0).getEndTime())){
                    val = "设计委托审核中";
                }else if (sjCount ==1 &
                        (histories.get(0).getName().equals("技经人员审预算")||histories.get(0).getName().equals("联合审图")) &
                        StringUtils.isNotEmpty(histories.get(0).getEndTime())){
                    val = "设计委托审核完成";
                }else if (sjCount >1 & (histories.get(0).getName().equals("项目经理审图") ||
                        histories.get(0).getName().equals("联合审图") ||
                        histories.get(0).getName().equals("技经人员审预算")) &
                        StringUtils.isEmpty(histories.get(0).getEndTime())){
                    val = "设计委托修改审核中";
                }else if (sjCount >1 &
                        (histories.get(0).getName().equals("技经人员审预算")||histories.get(0).getName().equals("联合审图")) &
                        StringUtils.isNotEmpty(histories.get(0).getEndTime())){
                    val = "设计委托修改审核完成";
                }

            }
        }else {
            val = "设计委托未发起";
        }
        return val;
    }
}
