package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service;

import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.service.CrudService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.StandardDetail;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.ConstructeScale;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.mapper.ConstructeScaleMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 储备项目建设规模统计表
 *
 * @author: 王强
 * @create: 2022-08-19 14:13
 **/
@Service
@Transactional(readOnly = true)
public class ConstructeScaleService extends CrudService<ConstructeScaleMapper, ConstructeScale> {

    @Autowired
    private ConstructeScaleMapper dao;

    /**
     * 获取所有的  项目储备编号
     * @return
     */
    public List<String> getAllProId(){
        return dao.getAllProId();
    }

    @Transactional(readOnly = false)
    public void insertList(@Param("list") List<ConstructeScale> list) {
        List<ConstructeScale> scaleList = dao.exportFindList(null);
        for (ConstructeScale constructeScale : list) {
            scaleList.forEach(sc->{
                if (sc.getProjectReserveId().equals(constructeScale.getProjectReserveId())){
                    dao.deleteByProId(sc.getProjectReserveId());
                }
            });
            constructeScale.preInsert();
        }
        dao.insertList(list);
    }

    public Page<ConstructeScale> findPage(Page<ConstructeScale> page, ConstructeScale constructeScale) {
        Page<ConstructeScale> pageList = super.findPage(page, constructeScale);
        return pageList;
    }

    /**
     * 删除方法
     *
     * @param proId
     */
    @Transactional(readOnly = false)
    public void deleteByProId(String proId) {
        dao.deleteByProId(proId);
    }

    public List<ConstructeScale> exportFindList(ConstructeScale constructeScale) {
        List<ConstructeScale> pageList = dao.exportFindList(constructeScale);
        return pageList;
    }

    public String getByProjectReserveId(String projectReserveId) {
        return dao.getByProjectReserveId(projectReserveId);
    }

    public List<History> getHistoryByExecuteId(String executeId) {
        return dao.getHistoryByExecuteId(executeId);
    }

    public List<StandardDetail> getStandardDetail() {
        return dao.getStandardDetail();
    }

    public List<MaterialData> getMaterialData(String projectName) {
        return dao.getMaterialData(projectName);
    }

}
