package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.Cable;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.CableService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 电缆段长统计表 controller
 * @author: 王强
 * @create: 2022-11-04 09:04
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/cable")
public class CableController extends BaseController {

    @Autowired
    private CableService cableService;

    @ModelAttribute
    public Cable get(@RequestParam(required = false) String id) {
        Cable entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = cableService.get(id);
        }
        if (entity == null) {
            entity = new Cable();
        }
        return entity;
    }

    /**
     * 电缆段长统计表页面
     * @param cable
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:cable:list")
    @RequestMapping(value = "cableList")
    public String budgetList(Cable cable, Model model) {
        model.addAttribute("cable", cable);
        return "modules/cg/statisticalTable/cable/cable";
    }

    /**
     * 储备项目概预算数据列表
     * @param cable
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:cable:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(Cable cable, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<Cable> page = cableService.findPage(new Page<Cable>(request, response), cable);

        List<Cable> list = page.getList();
        List<Cable> cableList = new ArrayList<>();
        Cable ca = null;
        for (int i=0;i<list.size();i++){
            ca = list.get(i);
            //进行赋值操作
            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = cableService.getByProjectName(ca.getProjectName());
            Double sum1 = 0.0;
            Double sum2 = 0.0;
            Double sum3 = 0.0;
            cableList.add(ca);
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500108108") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,400,3,22,ZC,无阻水")){
                        sum1 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,400,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum1 + "");
                        cableList.add(ca);
                    }else if (dataList.get(j).getMaterialCode().equals("500108302") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,240,3,22,ZC,无阻水")){
                        sum2 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,240,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum2 + "");
                        cableList.add(ca);
                    }else if (dataList.get(j).getMaterialCode().equals("500108478") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,70,3,22,ZC,无阻水")){
                        sum3 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,70,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum3 + "");
                        cableList.add(ca);
                    } else {
                        ca.setSpecifications("");
                        ca.setDesignCableLength("");
                    }
                }
            } else {
                ca.setSpecifications("");
                ca.setDesignCableLength("");
            }

        }

        return getBootstrapData(page);
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:cable:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            cableService.deleteByProId(cableService.get(id).getProjectReserveId());
        }
        j.setMsg("删除电缆段长统计表信息成功");
        return j;
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:cable:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);
            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = cableService.getAllProId();
            //获取导入表格所有数据
            List<Cable> cables = ExcelImportUtil.getCableUtil(importUtil,proIdList);
            cableService.insertList(cables);
        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入储备项目概预算信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:cable:export")
    @RequestMapping(value = "export")
    public void exportExcel(Cable cable, HttpServletRequest request, HttpServletResponse response) throws ParseException {
        List<Cable> list = cableService.exportFindList(cable);

        List<Cable> cableList = new ArrayList<>();
        Cable ca = null;
        for (int i=0;i<list.size();i++){
            ca = list.get(i);
            //进行赋值操作
            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = cableService.getByProjectName(ca.getProjectName());
            Double sum1 = 0.0;
            Double sum2 = 0.0;
            Double sum3 = 0.0;
            cableList.add(ca);
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500108108") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,400,3,22,ZC,无阻水")){
                        sum1 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,400,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum1 + "");
                        cableList.add(ca);
                    }else if (dataList.get(j).getMaterialCode().equals("500108302") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,240,3,22,ZC,无阻水")){
                        sum2 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,240,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum2 + "");
                        cableList.add(ca);
                    }else if (dataList.get(j).getMaterialCode().equals("500108478") &
                            dataList.get(j).getMaterialName().equals("电力电缆,AC10kV,YJV,70,3,22,ZC,无阻水")){
                        sum3 += Double.parseDouble(dataList.get(j).getTotalCount());
                        ca.setSpecifications("电力电缆,AC10kV,YJV,70,3,22,ZC,无阻水");
                        ca.setDesignCableLength(sum3 + "");
                        cableList.add(ca);
                    } else {
                        ca.setSpecifications("");
                        ca.setDesignCableLength("");
                    }
                }
            } else {
                ca.setSpecifications("");
                ca.setDesignCableLength("");
            }

        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("cable");
        util.exportCable(response,workbook,cableList);
    }
}
