package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.EnginnerQuery;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.BudgetStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.EnginnerQueryService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 立杆和土建工程量统计
 * @author: 王强
 * @create: 2022-08-22 15:19
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/enginnerQuery")
public class EnginnerQueryController extends BaseController {

    @Autowired
    private EnginnerQueryService queryService;

    @Autowired
    private BudgetStatsService budgetStatsService;

    @ModelAttribute
    public EnginnerQuery get(@RequestParam(required = false) String id) {
        EnginnerQuery entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = queryService.get(id);
        }
        if (entity == null) {
            entity = new EnginnerQuery();
        }
        return entity;
    }

    /**
     * 立杆和土建工程量统计列表页面
     * @param enginnerQuery
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:enginnerQuery:list")
    @RequestMapping(value = "queryList")
    public String budgetList(EnginnerQuery enginnerQuery, Model model) {
        model.addAttribute("enginnerQuery", enginnerQuery);
        return "modules/cg/statisticalTable/enginnerQuery/enginnerQuery";
    }

    /**
     * 立杆和土建工程量统计数据列表
     * @param enginnerQuery
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:enginnerQuery:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(EnginnerQuery enginnerQuery, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<EnginnerQuery> page = queryService.findPage(new Page<EnginnerQuery>(request, response), enginnerQuery);
        List<EnginnerQuery> list = page.getList();
        List<EnginnerQuery> queryList = new ArrayList<>();
        EnginnerQuery query = null;
        for (int i=0;i<list.size();i++){
            query = list.get(i);
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = queryService.getByProjectReserveId(query.getProjectReserveId());
            //设置储备进度
            query.setReserveProgress(budgetStatsService.getReserveProgress(query.getProjectReserveId()));

            //设置立杆信息数据
            Double sum1 = 0.0;
            Double sum2 = 0.0;
            Double sum3 = 0.0;
            Double sum4 = 0.0;
            Double sum5 = 0.0;
            Double sum6 = 0.0;
            Double guan1 = 0.0;
            Double guan2 = 0.0;
            Double guan3 = 0.0;
            Double guan4 = 0.0;
            Double guan5 = 0.0;
            Double guan6 = 0.0;
            Double guan7 = 0.0;
            Double guan8 = 0.0;
            Double guan9 = 0.0;
            Double guan10 = 0.0;
            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = queryService.getByProjectName(query.getProjectName());
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500033660")){
                        sum1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500013972")){
                        sum2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500013974")){
                        sum3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500033743")){
                        sum4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("乙供") &
                            dataList.get(j).getExtendDescription().equals("等径水泥杆,300mm,9m,18φ16,下")){
                        sum5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500124726")){
                        sum6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-B") &
                            dataList.get(j).getNote().equals("每基6.18吨（含基础+地脚螺栓）")){
                        guan1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-B") &
                            dataList.get(j).getNote().equals("每基2.78吨（不含基础，含地脚螺栓）")){
                        guan2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-D") &
                            dataList.get(j).getNote().equals("每基6.42吨（含基础+地脚螺栓）")){
                        guan3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-D") &
                            dataList.get(j).getNote().equals("每基3.02吨（不含基础，含地脚螺栓）")){
                        guan4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-B") &
                            dataList.get(j).getNote().equals("每基8.71吨（含基础+地脚螺栓）")){
                        guan5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-B") &
                            dataList.get(j).getNote().equals("每基4.01吨（不含基础，含地脚螺栓）")){
                        guan6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-E") &
                            dataList.get(j).getNote().equals("每基8.1吨（含基础+地脚螺栓）")){
                        guan7 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-E") &
                            dataList.get(j).getNote().equals("每基4.31吨（不含基础，含地脚螺栓）")){
                        guan8 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH39-13-B") &
                            dataList.get(j).getNote().equals("每基11.24吨（含基础+地脚螺栓）")){
                        guan9 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH39-13-B") &
                            dataList.get(j).getNote().equals("每基5.8吨（不含基础，含地脚螺栓）")){
                        guan10 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                }
            }
            query.setPole190X10(doubleToString(sum1));
            query.setPole190X12(doubleToString(sum2));
            query.setPole190X15(doubleToString(sum3));
            query.setPole230X15("");
            query.setPole230X18(doubleToString(sum4));
            query.setPole300X9(doubleToString(sum5));
            query.setPole350X15(doubleToString(sum6));
            //设置钢管杆信息
            query.setSteelPipeGNH31Contains(doubleToString(guan1));
            query.setSteelPipeGNH31NoContains(doubleToString(guan2));
            query.setSteelPipeGNH3113DContains(doubleToString(guan3));
            query.setSteelPipeGNH3113DNoContains(doubleToString(guan4));
            query.setSteelPipeCNH35Contains(doubleToString(guan5));
            query.setSteelPipeCNH35NoContains(doubleToString(guan6));
            query.setSteelPipeCNH3513EContains(doubleToString(guan7));
            query.setSteelPipeCNH3513ENoContains(doubleToString(guan8));
            query.setSteelPipeCNH39Contains(doubleToString(guan9));
            query.setSteelPipeCNH39NoContains(doubleToString(guan10));
            query.setPrefabricatedWell("");
            query.setPrefabricatedBase("");
            query.setPrefabricatedPackage("");

            query.setCivilWork("");
            query.setPoleWorkload("");
            query.setProjectType("");
            queryList.add(query);
        }
        page.setList(queryList);
        return getBootstrapData(page);
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:enginnerQuery:export")
    @RequestMapping(value = "export")
    public void exportExcel(EnginnerQuery enginnerQuery, HttpServletRequest request, HttpServletResponse response) {
        List<EnginnerQuery> list = queryService.exportFindList(enginnerQuery);

        List<EnginnerQuery> queryList = new ArrayList<>();
        EnginnerQuery query = null;
        for (int i=0;i<list.size();i++){
            query = list.get(i);
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = queryService.getByProjectReserveId(query.getProjectReserveId());
            //设置储备进度
            query.setReserveProgress(budgetStatsService.getReserveProgress(query.getProjectReserveId()));

            //设置立杆信息数据
            Double sum1 = 0.0;
            Double sum2 = 0.0;
            Double sum3 = 0.0;
            Double sum4 = 0.0;
            Double sum5 = 0.0;
            Double sum6 = 0.0;
            Double guan1 = 0.0;
            Double guan2 = 0.0;
            Double guan3 = 0.0;
            Double guan4 = 0.0;
            Double guan5 = 0.0;
            Double guan6 = 0.0;
            Double guan7 = 0.0;
            Double guan8 = 0.0;
            Double guan9 = 0.0;
            Double guan10 = 0.0;
            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = queryService.getByProjectName(query.getProjectName());
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500033660")){
                        sum1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500013972")){
                        sum2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500013974")){
                        sum3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500033743")){
                        sum4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("乙供") &
                            dataList.get(j).getExtendDescription().equals("等径水泥杆,300mm,9m,18φ16,下")){
                        sum5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500124726")){
                        sum6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-B") &
                            dataList.get(j).getNote().equals("每基6.18吨（含基础+地脚螺栓）")){
                        guan1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-B") &
                            dataList.get(j).getNote().equals("每基2.78吨（不含基础，含地脚螺栓）")){
                        guan2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-D") &
                            dataList.get(j).getNote().equals("每基6.42吨（含基础+地脚螺栓）")){
                        guan3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH31-13-D") &
                            dataList.get(j).getNote().equals("每基3.02吨（不含基础，含地脚螺栓）")){
                        guan4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-B") &
                            dataList.get(j).getNote().equals("每基8.71吨（含基础+地脚螺栓）")){
                        guan5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-B") &
                            dataList.get(j).getNote().equals("每基4.01吨（不含基础，含地脚螺栓）")){
                        guan6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-E") &
                            dataList.get(j).getNote().equals("每基8.1吨（含基础+地脚螺栓）")){
                        guan7 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH35-13-E") &
                            dataList.get(j).getNote().equals("每基4.31吨（不含基础，含地脚螺栓）")){
                        guan8 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH39-13-B") &
                            dataList.get(j).getNote().equals("每基11.24吨（含基础+地脚螺栓）")){
                        guan9 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getExtendDescription().equals("配农网用,整套杆,GNH39-13-B") &
                            dataList.get(j).getNote().equals("每基5.8吨（不含基础，含地脚螺栓）")){
                        guan10 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                }
            }
            query.setPole190X10(doubleToString(sum1));
            query.setPole190X12(doubleToString(sum2));
            query.setPole190X15(doubleToString(sum3));
            query.setPole230X15("");
            query.setPole230X18(doubleToString(sum4));
            query.setPole300X9(doubleToString(sum5));
            query.setPole350X15(doubleToString(sum6));
            //设置钢管杆信息
            query.setSteelPipeGNH31Contains(doubleToString(guan1));
            query.setSteelPipeGNH31NoContains(doubleToString(guan2));
            query.setSteelPipeGNH3113DContains(doubleToString(guan3));
            query.setSteelPipeGNH3113DNoContains(doubleToString(guan4));
            query.setSteelPipeCNH35Contains(doubleToString(guan5));
            query.setSteelPipeCNH35NoContains(doubleToString(guan6));
            query.setSteelPipeCNH3513EContains(doubleToString(guan7));
            query.setSteelPipeCNH3513ENoContains(doubleToString(guan8));
            query.setSteelPipeCNH39Contains(doubleToString(guan9));
            query.setSteelPipeCNH39NoContains(doubleToString(guan10));
            query.setPrefabricatedWell("");
            query.setPrefabricatedBase("");
            query.setPrefabricatedPackage("");

            query.setCivilWork("");
            query.setPoleWorkload("");
            query.setProjectType("");
            queryList.add(query);
        }

        //生成序列号
        int i = 1;
        for (EnginnerQuery s : queryList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("enginnerQuery");
        util.exportEnginnerQuery(response,workbook,queryList);
    }

    public String doubleToString(Double value){
        if (value == 0.0){
            return "";
        }else {
            return value + "";
        }
    }
}
