package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.PropertiesLoader;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.core.web.Servlets;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.Demolite;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.DocumentInfo;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.DemoliteService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveProcessProjectService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.utils.ReserveProcessProjectProUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.NormativeAudit;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.BudgetStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.NormativeAuditService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mock.web.MockMultipartFile;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 储备项目规范性审核记录表
 * @author: 王强
 * @create: 2022-08-23 11:03
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/normative")
public class NormativeAuditController extends BaseController {

    /**
     * 判断服务器系统类型，1是windows系统，2是linux系统
     */
    public static final String SYS_TYPE = System.getProperty("os.name").toLowerCase().startsWith("win") ? "1" : "2";

    /**
     * 属性文件加载对象
     */
    private static PropertiesLoader loader = new PropertiesLoader("/properties/jeeplus.properties");

    @Autowired
    private ReserveProcessProjectService projectService;

    @Autowired
    private DemoliteService demoliteService;

    @Autowired
    private NormativeAuditService auditService;

    @Autowired
    private BudgetStatsService statsService;

    @ModelAttribute
    public NormativeAudit get(@RequestParam(required = false) String id) {
        NormativeAudit entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = auditService.get(id);
        }
        if (entity == null) {
            entity = new NormativeAudit();
        }
        return entity;
    }

    /**
     * 储备项目规范性审核记录表页面
     * @param normativeAudit
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:normative:list")
    @RequestMapping(value = "normativeList")
    public String normativeList(NormativeAudit normativeAudit, Model model) {
        model.addAttribute("normativeAudit", normativeAudit);
        return "modules/cg/statisticalTable/normative/normative";
    }

    /**
     * 特殊物资统计数据列表
     * @param normativeAudit
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:normative:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(NormativeAudit normativeAudit, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<NormativeAudit> page = auditService.findPage(new Page<NormativeAudit>(request, response), normativeAudit);
        List<NormativeAudit> list = page.getList();
        List<NormativeAudit> auditList = new ArrayList<>();
        NormativeAudit audit = null;
        for (int i=0;i<list.size();i++){
            audit = list.get(i);
            //进行赋值操作
            //设置储备进度
            audit.setReserveProgress(statsService.getReserveProgress(audit.getProjectReserveId()));
            //设置概预算调整
            audit.setDesignAdjustment("");
            audit.setDesignAdjustmentDate("");
            //设置完整性校核相关值
//            audit.setBlueprint(audit.getBlueprint() ==null ? "" : audit.getBlueprint());
//            audit.setBudgetBook(audit.getBudgetBook() ==null ? "" : audit.getBudgetBook());
//            audit.setDesignManual(audit.getDesignManual() ==null ? "" : audit.getDesignManual());
//
//            audit.setProjectProposal(audit.getProjectProposal() ==null ? "" : audit.getProjectProposal());
            //设置拆旧清册
//            int count = auditService.getCountByProjectReserveId(audit.getProjectReserveId());
//            audit.setOldInventoryDemolition(count >0 ? "有" : null);

            auditList.add(audit);
        }
        page.setList(auditList);
        return getBootstrapData(page);
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:normative:export")
    @RequestMapping(value = "export")
    public void exportExcel(NormativeAudit normativeAudit, HttpServletRequest request, HttpServletResponse response) {
        List<NormativeAudit> list = auditService.exportFindList(normativeAudit);

        List<NormativeAudit> auditList = new ArrayList<>();
        NormativeAudit audit = null;
        for (int i=0;i<list.size();i++){
            audit = list.get(i);
            //进行赋值操作
            //设置储备进度
            audit.setReserveProgress(statsService.getReserveProgress(audit.getProjectReserveId()));
            //对文件路径进行截取操作，只需要他的文件名称
            audit.setBlueprint(fileNameSubString(audit.getBlueprint()));
            audit.setBudgetBook(fileNameSubString(audit.getBudgetBook()));
            audit.setDesignManual(fileNameSubString(audit.getDesignManual()));
            audit.setMaterialList(fileNameSubString(audit.getMaterialList()));
            audit.setProjectProposal(fileNameSubString(audit.getProjectProposal()));
            audit.setOldInventoryDemolition(fileNameSubString(audit.getOldInventoryDemolition()));
            audit.setNoStopWorkPlan(fileNameSubString(audit.getNoStopWorkPlan()));
            audit.setCastPlaceApprovalForm(fileNameSubString(audit.getCastPlaceApprovalForm()));
            auditList.add(audit);
        }

        //生成序列号
        int i = 1;
        for (NormativeAudit s : auditList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("normative");
        util.exportNormative(response,workbook,auditList);
    }

    /**
     * 专职人员增加，编辑表单页面
     * @param normativeAudit
     * @param model
     * @return
     */
    @RequiresPermissions(value={"cg:reservemanagementcenter:normative:edit"},logical= Logical.OR)
    @RequestMapping(value = "form")
    public String form(NormativeAudit normativeAudit, Model model) {
        model.addAttribute("normativeAudit", normativeAudit);
        return "modules/cg/statisticalTable/normative/normativeEdit";
    }

    /**
     * 修改表单
     * @param audit
     * @return
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:companyReview:edit"},logical=Logical.OR)
    @RequestMapping(value = "update")
    public AjaxJson update(NormativeAudit audit) throws IOException, InvalidFormatException, ParseException {
        AjaxJson j = new AjaxJson();
        /**
         * 后台hibernate-validation插件校验
         */
        String errMsg = beanValidator(audit);
        if (StringUtils.isNotBlank(errMsg)){
            j.setSuccess(false);
            j.setMsg(errMsg);
            return j;

        }
        //根据流程状态，当流程进行中或完成时，不允许修改
        int processStatus = projectService.getProcessStatus(audit.getProjectReserveId());
        if (processStatus != 1 & processStatus != 2){
            //对文件数据进行处理
            //1、将上传的所有文件的路径放到 cg_document_info（流程文件信息表）中
            auditService.updateDocumentInfo(audit);
            //2、拆旧清册需要进行 持久化操作
            //在将拆旧清册数据存入数据库前先查出库中有没有这个project ReserveId的相关数据
            //先判断  拆旧清册的文件与原数据库中的文件是否是同一个文件，是同一个，则不需要进行持久化
            DocumentInfo info = auditService.getByProId(audit.getProjectReserveId());
            if (!info.getDemolition().equals(audit.getOldInventoryDemolition())){
                String projectReserveId = audit.getProjectReserveId();
                demoliteService.deleteByProjectReserveId(projectReserveId);
                //获取拆旧清册数据
                //String index out of range: -1 这个异常一般是截取字符串时报的错误。
                File file = new File(audit.getOldInventoryDemolition());
                String path = file.getAbsolutePath();
                int index = file.getAbsolutePath().indexOf("fileServer");

                String FILE_PREFIX = loader.getProperty("linux.file.store.prefix");

                if (SYS_TYPE.equals("1")) {
                    path = path.substring(index-1);

                } else {
                    //liunx file store prefix
                    path = FILE_PREFIX + Servlets.getRequest().getContextPath() + path.substring(index-1);
                    path = path.replaceAll("\\\\","/");
                }

                File demoFile = new File(path);

                InputStream inputStream = new FileInputStream(demoFile);
                MultipartFile multipartFile = new MockMultipartFile("file", demoFile.getName(), null, inputStream);
                ImportUtil importUtil = new ImportUtil(multipartFile, 0, 0);
                //获取导入表格所有数据
                List<Demolite> reserveManagementList = ReserveProcessProjectProUtil.getDemoliteUtil(importUtil, projectReserveId);
                //将数据存入数据库
                demoliteService.insertList(reserveManagementList);

            }
        }

        return j;
    }

    public String fileNameSubString(String fileName){
        //可能是多个文件的情况
        //1、先拆分
        if (StringUtils.isNotEmpty(fileName)){
            String[] split = fileName.split("\\|");
            String name = "";
            for (int i=0;i<split.length;i++){
                //截取字符串
                //1、查找最后一次/出现的位置
                int i1 = split[i].lastIndexOf("/");
                String substring = split[i].substring(i1+1);
                if (StringUtils.isNotEmpty(name)){
                    name = name + "," + substring;
                }else {
                    name = substring;
                }
            }
            return name;
        }else {
            return "";
        }

    }
}
