package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.entity.FeedBackBudget;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.ReserveProcessProjectService;
import com.jeeplus.modules.cg.reservemanagementcenter.reserveManage.service.SummaryStatisticService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.History;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.ProgressStats;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.BudgetStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.ProgressStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author: 王强
 * @create: 2022-08-18 09:20
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/progressStats")
public class ProgressStatsController extends BaseController {

    @Autowired
    private ProgressStatsService statsService;

    @Autowired
    private BudgetStatsService budgetStatsService;

    @Autowired
    private SummaryStatisticService statisticService;

    @Autowired
    private ReserveProcessProjectService projectService;

    @ModelAttribute
    public ProgressStats get(@RequestParam(required = false) String id) {
        ProgressStats entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = statsService.get(id);
        }
        if (entity == null) {
            entity = new ProgressStats();
        }
        return entity;
    }

    /**
     * 储备项目概预算列表页面
     * @param progressStats
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:progressStats:list")
    @RequestMapping(value = "progressList")
    public String progressList(ProgressStats progressStats, Model model) {
        model.addAttribute("progressStats", progressStats);
        return "modules/cg/statisticalTable/progressStats/progressStats";
    }

    /**
     * 储备进度统计表数据列表
     * @param progressStats
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:progressStats:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(ProgressStats progressStats, HttpServletRequest request, HttpServletResponse response, Model model) throws ParseException {

        Page<ProgressStats> page = statsService.findPage(new Page<ProgressStats>(request, response), progressStats);
        List<ProgressStats> list = page.getList();
        List<ProgressStats> statsList = new ArrayList<>();
        ProgressStats stats = null;
        for (int i=0;i<list.size();i++){
            //进行赋值操作
            //查出proc_ins_id
            stats = list.get(i);
            //设置储备进度
            stats.setReserveProgress(budgetStatsService.getReserveProgress(stats.getProjectReserveId()));
            //设置是否发出设计委托
            if (!stats.getReserveProgress().equals("设计委托未发起")){
                stats.setDesignCommission("是");
            }else {
                stats.setDesignCommission("否");
            }
            //设置设计委托发起时间    从历史表中获取最近的设计单位结束时间
            String procInsId = statsService.getByProjectReserveId(stats.getProjectReserveId());
            List<History> history = statsService.getHistoryByProInsId(procInsId, "设计单位上传文件");
            if (history.size()>0){
                stats.setDesignCommissionIssueTime(history.get(0).getStartTime());
                //设置初设提交时间
                stats.setSubmitTime(history.get(history.size()-1).getStartTime());
                //设置是否完成初设
                if (StringUtils.isNotEmpty(stats.getSubmitTime())){
                    stats.setCompleteDesign("是");
                }else {
                    stats.setCompleteDesign("否");
                }
                //设置是否进行审图
                if (StringUtils.isNotEmpty(history.get(0).getEndTime())){
                    stats.setCompleteDraw("是");
                    stats.setCompleteDrawDate(history.get(0).getEndTime());
                }else {
                    stats.setCompleteDraw("否");
                    stats.setCompleteDrawDate("");
                }
                //设置是否通过图纸审核  查出最近的项目经理审图节点数据，根据他的结束时间查是否有下一个节点
                List<History> jlHis = statsService.getHistoryByProInsId(procInsId, "项目经理审图");
                List<History> lhHis = statsService.getHistoryByProInsId(procInsId, "联合审图");
                List<History> gysHis = statsService.getHistoryByProInsId(procInsId, "技经人员审预算");
                int status = projectService.getProcessStatus(stats.getProjectReserveId());

                //从反馈表中查
                FeedBackBudget feBook = statsService.getByProId(stats.getProjectReserveId());
                if (jlHis.size()>0){
                    if (StringUtils.isNotEmpty(jlHis.get(0).getEndTime())){
                        if (jlHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                            //说明是不通过
                            stats.setDrawAudit("不通过");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置未通过原因分析

                            String info = "";
                            if (StringUtils.isNotEmpty(feBook.getDrawingAndSiteProblem())){
                                info = feBook.getDrawingAndSiteProblem();
                            }
                            if (StringUtils.isNotEmpty(feBook.getCommunicationProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getCommunicationProblem();
                                }else {
                                    info = feBook.getCommunicationProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getCivilPrefabricateProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getCivilPrefabricateProblem();
                                }else {
                                    info = feBook.getCivilPrefabricateProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getLiveWorkNumProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getLiveWorkNumProblem();
                                }else {
                                    info = feBook.getLiveWorkNumProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getProjectManagerOtherProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getProjectManagerOtherProblem();
                                }else {
                                    info = feBook.getProjectManagerOtherProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(info)){
                                stats.setReasonForFailure(info);
                            }
                            stats.setReasonForFailure("");
                            //设置是否需设计变更
                            stats.setChangeDesign("是");
                        }else if (gysHis.get(0).getStartTime().equals(jlHis.get(0).getEndTime())){
                            //说明是通过
                            stats.setDrawAudit("通过");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }else if (status == 3){
                            //取消
                            stats.setDrawAudit("取消");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }else if (status == 4){
                            stats.setDrawAudit("待定");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }
                    }
                }
                //设置概预算审核是否进行审核
                if (gysHis.size()>0){
                    if (StringUtils.isNotEmpty(gysHis.get(0).getEndTime())){
                        if (gysHis.get(0).getStartTime().equals(jlHis.get(0).getEndTime())){
                            stats.setWhetherToAudit("是");
                            //设置概预算审核日期
                            stats.setAuditDate(gysHis.get(0).getStartTime());
                            //设置是否通过专家审核
                            if (StringUtils.isNotEmpty(gysHis.get(0).getEndTime())){
                                if (gysHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                                    //说明是未通过
                                    stats.setExpertReview("不通过");
                                    //设置通过审核日期
                                    stats.setEstimatePassAuditDate(gysHis.get(0).getEndTime());
                                    //设置未通过原因分析
                                    String info = "";
                                    if (StringUtils.isNotEmpty(feBook.getPreferedCase())){
                                        info = feBook.getPreferedCase();
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getTransferSituation())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getTransferSituation();
                                        }else {
                                            info = feBook.getTransferSituation();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getBudgetTemplateCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getBudgetTemplateCheck();
                                        }else {
                                            info = feBook.getBudgetTemplateCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getQuotaApplicationCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getQuotaApplicationCheck();
                                        }else {
                                            info = feBook.getQuotaApplicationCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getWorkLoadCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getWorkLoadCheck();
                                        }else {
                                            info = feBook.getWorkLoadCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getCheckTheFee())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getCheckTheFee();
                                        }else {
                                            info = feBook.getCheckTheFee();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getSupplyCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getSupplyCheck();
                                        }else {
                                            info = feBook.getSupplyCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getMaterialCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getMaterialCheck();
                                        }else {
                                            info = feBook.getMaterialCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getLiveWorkFeeCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getLiveWorkFeeCheck();
                                        }else {
                                            info = feBook.getLiveWorkFeeCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getDemolitionEngineeringProblems())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getDemolitionEngineeringProblems();
                                        }else {
                                            info = feBook.getDemolitionEngineeringProblems();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getOtherProblem())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getOtherProblem();
                                        }else {
                                            info = feBook.getOtherProblem();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(info)){
                                        stats.setEstimateReasonForFailure(info);
                                    } else {
                                        stats.setEstimateReasonForFailure("");
                                    }

                                    //设置是否需设计变更
                                    stats.setEstimateChangeDesign("是");
                                }else {
                                    //说明是通过
                                    stats.setExpertReview("通过");
                                    //设置通过审核日期
                                    stats.setEstimatePassAuditDate(gysHis.get(0).getEndTime());
                                    //设置是否需设计变更
                                    stats.setEstimateChangeDesign("否");
                                }
                            }
                        }else {
                            stats.setWhetherToAudit("否");
                        }
                    }
                }

                //设置是否进行图纸审查
                if (lhHis.size()>0){
                    if (StringUtils.isNotEmpty(lhHis.get(0).getEndTime())){
                        if (lhHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                            stats.setDrawingReview("是");
                            //设置联合审图日期
                            stats.setReviewDate(lhHis.get(0).getStartTime());
                            //设置是否通过图纸审查
                            if (StringUtils.isNotEmpty(lhHis.get(0).getEndTime())){
                                //设置审图意见  从历史意见表中根据时间获取
                                String comment = statsService.getCommentByProInsId(procInsId,lhHis.get(0).getEndTime());
                                if (lhHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                                    //说明是不通过
                                    stats.setPassDrawingReview("不通过");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    //设置审图意见
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else if (status == 3){
                                    //取消
                                    stats.setPassDrawingReview("取消");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else if (status == 4){
                                    //取消
                                    stats.setPassDrawingReview("待定");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else {
                                    //通过
                                    stats.setPassDrawingReview("通过");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("否");
                                }
                            }
                        } else {
                            //设置是否进行图纸审查
                            stats.setDrawingReview("");
                            //设置联合审图日期
                            stats.setReviewDate("");
                            //设置是否通过图纸审查
                            stats.setPassDrawingReview("");
                            //设置通过联合审图日期
                            stats.setApprovedDate("");
                            //设置审图意见
                            stats.setReviewComment("");
                            //设置是否需设计变更
                            stats.setJointReviewDesignChange("");
                        }
                    }
                }
                //设置定稿日期
                if (StringUtils.isNotEmpty(stats.getPassAuditDate()) &
                        StringUtils.isNotEmpty(stats.getPassProvincialCompanyReview()) &
                        StringUtils.isNotEmpty(stats.getApprovedDate())){
                    Date timeByProID = budgetStatsService.getTimeByProID(stats.getProjectReserveId());
                    SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    Date date1 = format.parse(stats.getPassAuditDate());
                    Date date2 = format.parse(stats.getApprovedDate());
                    if (timeByProID.before(date1)){
                        if (date1.before(date2)) {
                            stats.setFinalDate(format.format(date2));
                        }else {
                            stats.setFinalDate(format.format(date1));
                        }
                    }else {
                        if (timeByProID.before(date2)){
                            stats.setFinalDate(format.format(date2));
                        }else {
                            stats.setFinalDate(format.format(timeByProID));
                        }
                    }
                    //设置图纸是否定稿
                    if (StringUtils.isNotEmpty(stats.getFinalDate())){
                        stats.setDrawingFinalize("是");
                    }else {
                        stats.setDrawingFinalize("否");
                    }
                } else {
                    //设置图纸是否定稿
                    stats.setDrawingFinalize("");
                    stats.setFinalDate("");
                    stats.setTransferProjectCenterDate("");
                    stats.setTransferToConstructionUnitDate("");
                }

            } else {
                stats = setStatsValue(stats);
            }

            statsList.add(stats);
        }
        page.setList(statsList);
//        System.out.println(list);
        return getBootstrapData(page);
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:progressStats:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            statsService.deleteByProId(statsService.get(id).getProjectReserveId());
        }
        j.setMsg("删除储备进度统计表信息成功");
        return j;
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:progressStats:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);

            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = statsService.getAllProId();
            //获取导入表格所有数据
            List<ProgressStats> budgetStats = ExcelImportUtil.getProgressUtil(importUtil,proIdList);
            statsService.insertList(budgetStats);
        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入储备进度信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:progressStats:export")
    @RequestMapping(value = "export")
    public void exportExcel(ProgressStats progressStats, HttpServletRequest request, HttpServletResponse response) throws ParseException {
        List<ProgressStats> list = statsService.exportFindList(progressStats);

        List<ProgressStats> statsList = new ArrayList<>();
        ProgressStats stats = null;
        for (int i=0;i<list.size();i++){
            //进行赋值操作
            //查出proc_ins_id
            stats = list.get(i);
            //设置储备进度
            stats.setReserveProgress(budgetStatsService.getReserveProgress(stats.getProjectReserveId()));
            //设置是否发出设计委托
            if (!stats.getReserveProgress().equals("设计委托未发起")){
                stats.setDesignCommission("是");
            }else {
                stats.setDesignCommission("否");
            }
            //设置设计委托发起时间    从历史表中获取最近的设计单位结束时间
            String procInsId = statsService.getByProjectReserveId(stats.getProjectReserveId());
            List<History> history = statsService.getHistoryByProInsId(procInsId, "设计单位上传文件");
            if (history.size()>0){
                stats.setDesignCommissionIssueTime(history.get(0).getStartTime());
                //设置初设提交时间
                stats.setSubmitTime(history.get(history.size()-1).getStartTime());
                //设置是否完成初设
                if (StringUtils.isNotEmpty(stats.getSubmitTime())){
                    stats.setCompleteDesign("是");
                }else {
                    stats.setCompleteDesign("否");
                }
                //设置是否进行审图
                if (StringUtils.isNotEmpty(history.get(0).getEndTime())){
                    stats.setCompleteDraw("是");
                    stats.setCompleteDrawDate(history.get(0).getEndTime());
                }else {
                    stats.setCompleteDraw("否");
                    stats.setCompleteDrawDate("");
                }
                //设置是否通过图纸审核  查出最近的项目经理审图节点数据，根据他的结束时间查是否有下一个节点
                List<History> jlHis = statsService.getHistoryByProInsId(procInsId, "项目经理审图");
                List<History> lhHis = statsService.getHistoryByProInsId(procInsId, "联合审图");
                List<History> gysHis = statsService.getHistoryByProInsId(procInsId, "技经人员审预算");
                int status = projectService.getProcessStatus(stats.getProjectReserveId());

                //从反馈表中查
                FeedBackBudget feBook = statsService.getByProId(stats.getProjectReserveId());
                if (jlHis.size()>0){
                    if (StringUtils.isNotEmpty(jlHis.get(0).getEndTime())){
                        if (jlHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                            //说明是不通过
                            stats.setDrawAudit("不通过");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置未通过原因分析

                            String info = "";
                            if (StringUtils.isNotEmpty(feBook.getDrawingAndSiteProblem())){
                                info = feBook.getDrawingAndSiteProblem();
                            }
                            if (StringUtils.isNotEmpty(feBook.getCommunicationProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getCommunicationProblem();
                                }else {
                                    info = feBook.getCommunicationProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getCivilPrefabricateProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getCivilPrefabricateProblem();
                                }else {
                                    info = feBook.getCivilPrefabricateProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getLiveWorkNumProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getLiveWorkNumProblem();
                                }else {
                                    info = feBook.getLiveWorkNumProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(feBook.getProjectManagerOtherProblem())){
                                if (StringUtils.isNotEmpty(info)){
                                    info += "、" + feBook.getProjectManagerOtherProblem();
                                }else {
                                    info = feBook.getProjectManagerOtherProblem();
                                }
                            }
                            if (StringUtils.isNotEmpty(info)){
                                stats.setReasonForFailure(info);
                            }
                            stats.setReasonForFailure("");
                            //设置是否需设计变更
                            stats.setChangeDesign("是");
                        }else if (gysHis.get(0).getStartTime().equals(jlHis.get(0).getEndTime())){
                            //说明是通过
                            stats.setDrawAudit("通过");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }else if (status == 3){
                            //取消
                            stats.setDrawAudit("取消");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }else if (status == 4){
                            stats.setDrawAudit("待定");
                            //设置通过审核日期
                            stats.setPassAuditDate(jlHis.get(0).getEndTime());
                            //设置是否需设计变更
                            stats.setChangeDesign("否");
                            //设置未通过原因分析
                            stats.setReasonForFailure("");
                        }
                    }
                }
                //设置概预算审核是否进行审核
                if (gysHis.size()>0){
                    if (StringUtils.isNotEmpty(gysHis.get(0).getEndTime())){
                        if (gysHis.get(0).getStartTime().equals(jlHis.get(0).getEndTime())){
                            stats.setWhetherToAudit("是");
                            //设置概预算审核日期
                            stats.setAuditDate(gysHis.get(0).getStartTime());
                            //设置是否通过专家审核
                            if (StringUtils.isNotEmpty(gysHis.get(0).getEndTime())){
                                if (gysHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                                    //说明是未通过
                                    stats.setExpertReview("不通过");
                                    //设置通过审核日期
                                    stats.setEstimatePassAuditDate(gysHis.get(0).getEndTime());
                                    //设置未通过原因分析
                                    String info = "";
                                    if (StringUtils.isNotEmpty(feBook.getPreferedCase())){
                                        info = feBook.getPreferedCase();
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getTransferSituation())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getTransferSituation();
                                        }else {
                                            info = feBook.getTransferSituation();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getBudgetTemplateCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getBudgetTemplateCheck();
                                        }else {
                                            info = feBook.getBudgetTemplateCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getQuotaApplicationCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getQuotaApplicationCheck();
                                        }else {
                                            info = feBook.getQuotaApplicationCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getWorkLoadCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getWorkLoadCheck();
                                        }else {
                                            info = feBook.getWorkLoadCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getCheckTheFee())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getCheckTheFee();
                                        }else {
                                            info = feBook.getCheckTheFee();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getSupplyCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getSupplyCheck();
                                        }else {
                                            info = feBook.getSupplyCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getMaterialCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getMaterialCheck();
                                        }else {
                                            info = feBook.getMaterialCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getLiveWorkFeeCheck())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getLiveWorkFeeCheck();
                                        }else {
                                            info = feBook.getLiveWorkFeeCheck();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getDemolitionEngineeringProblems())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getDemolitionEngineeringProblems();
                                        }else {
                                            info = feBook.getDemolitionEngineeringProblems();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(feBook.getOtherProblem())){
                                        if (StringUtils.isNotEmpty(info)){
                                            info += "、" + feBook.getOtherProblem();
                                        }else {
                                            info = feBook.getOtherProblem();
                                        }
                                    }
                                    if (StringUtils.isNotEmpty(info)){
                                        stats.setEstimateReasonForFailure(info);
                                    } else {
                                        stats.setEstimateReasonForFailure("");
                                    }

                                    //设置是否需设计变更
                                    stats.setEstimateChangeDesign("是");
                                }else {
                                    //说明是通过
                                    stats.setExpertReview("通过");
                                    //设置通过审核日期
                                    stats.setEstimatePassAuditDate(gysHis.get(0).getEndTime());
                                    //设置是否需设计变更
                                    stats.setEstimateChangeDesign("否");
                                }
                            }
                        }else {
                            stats.setWhetherToAudit("否");
                        }
                    }
                }

                //设置是否进行图纸审查
                if (lhHis.size()>0){
                    if (StringUtils.isNotEmpty(lhHis.get(0).getEndTime())){
                        if (lhHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                            stats.setDrawingReview("是");
                            //设置联合审图日期
                            stats.setReviewDate(lhHis.get(0).getStartTime());
                            //设置是否通过图纸审查
                            if (StringUtils.isNotEmpty(lhHis.get(0).getEndTime())){
                                //设置审图意见  从历史意见表中根据时间获取
                                String comment = statsService.getCommentByProInsId(procInsId,lhHis.get(0).getEndTime());
                                if (lhHis.get(0).getEndTime().equals(history.get(0).getStartTime())){
                                    //说明是不通过
                                    stats.setPassDrawingReview("不通过");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    //设置审图意见
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else if (status == 3){
                                    //取消
                                    stats.setPassDrawingReview("取消");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else if (status == 4){
                                    //取消
                                    stats.setPassDrawingReview("待定");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    stats.setReviewComment(comment);
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("是");
                                }else {
                                    //通过
                                    stats.setPassDrawingReview("通过");
                                    //设置通过联合审图日期
                                    stats.setApprovedDate(lhHis.get(0).getEndTime());
                                    //设置是否需设计变更
                                    stats.setJointReviewDesignChange("否");
                                }
                            }
                        } else {
                            //设置是否进行图纸审查
                            stats.setDrawingReview("");
                            //设置联合审图日期
                            stats.setReviewDate("");
                            //设置是否通过图纸审查
                            stats.setPassDrawingReview("");
                            //设置通过联合审图日期
                            stats.setApprovedDate("");
                            //设置审图意见
                            stats.setReviewComment("");
                            //设置是否需设计变更
                            stats.setJointReviewDesignChange("");
                        }
                    }
                }
                //设置定稿日期
                if (StringUtils.isNotEmpty(stats.getPassAuditDate()) &
                        StringUtils.isNotEmpty(stats.getPassProvincialCompanyReview()) &
                        StringUtils.isNotEmpty(stats.getApprovedDate())){
                    Date timeByProID = budgetStatsService.getTimeByProID(stats.getProjectReserveId());
                    SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    Date date1 = format.parse(stats.getPassAuditDate());
                    Date date2 = format.parse(stats.getApprovedDate());
                    if (timeByProID.before(date1)){
                        if (date1.before(date2)) {
                            stats.setFinalDate(format.format(date2));
                        }else {
                            stats.setFinalDate(format.format(date1));
                        }
                    }else {
                        if (timeByProID.before(date2)){
                            stats.setFinalDate(format.format(date2));
                        }else {
                            stats.setFinalDate(format.format(timeByProID));
                        }
                    }
                    //设置图纸是否定稿
                    if (StringUtils.isNotEmpty(stats.getFinalDate())){
                        stats.setDrawingFinalize("是");
                    }else {
                        stats.setDrawingFinalize("否");
                    }
                } else {
                    //设置图纸是否定稿
                    stats.setDrawingFinalize("");
                    stats.setFinalDate("");
                    stats.setTransferProjectCenterDate("");
                    stats.setTransferToConstructionUnitDate("");
                }

            } else {
                stats = setStatsValue(stats);
            }

            statsList.add(stats);
        }
        //生成序列号
        int i = 1;
        for (ProgressStats s : statsList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("progressStats");
        util.exportProgress(response,workbook,statsList);
    }

    public ProgressStats setStatsValue(ProgressStats stats){
        //是否完成初设
        stats.setCompleteDesign("");
        //设置初设提交时间
        stats.setSubmitTime("");
        //设置是否进行审图
        stats.setCompleteDraw("");
        //设置审图日期
        stats.setCompleteDrawDate("");
        //设置设计委托发出时间
        stats.setDesignCommissionIssueTime("");
        //设置未通过原因分析
        stats.setReasonForFailure("");
        //是否通过图纸审核
        stats.setDrawAudit("");
        //设置通过审核日期
        stats.setPassAuditDate("");
        //设置是否需设计变更
        stats.setChangeDesign("");
        //设置概预算是否进行审核
        stats.setWhetherToAudit("");
        //设置概预算审核日期
        stats.setAuditDate("");
        //设置概预算是否通过专家审核
        stats.setExpertReview("");
        //设置通过审核日期
        stats.setEstimatePassAuditDate("");
        stats.setEstimateReasonForFailure("");
        stats.setEstimateChangeDesign("");
        //设置是否进行图纸审查
        stats.setDrawingReview("");
        //设置联合审图日期
        stats.setReviewDate("");
        //设置是否通过图纸审查
        stats.setPassDrawingReview("");
        //设置通过联合审图日期
        stats.setApprovedDate("");
        //设置审图意见
        stats.setReviewComment("");
        //设置是否需设计变更
        stats.setJointReviewDesignChange("");
        //设置图纸是否定稿
        stats.setDrawingFinalize("");
        stats.setFinalDate("");
        stats.setTransferProjectCenterDate("");
        stats.setTransferToConstructionUnitDate("");
        return stats;
    }
}
