package com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.web;

import com.jeeplus.common.json.AjaxJson;
import com.jeeplus.common.utils.StringUtils;
import com.jeeplus.core.persistence.Page;
import com.jeeplus.core.web.BaseController;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.MaterialData;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.entity.SpecialSupply;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.BudgetStatsService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.service.SpecialSupplyService;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelExportUtil;
import com.jeeplus.modules.cg.reservemanagementcenter.statisticalTable.util.ExcelImportUtil;
import com.jeeplus.modules.sg.managementcenter.materialproject.util.ImportUtil;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.apache.shiro.authz.annotation.Logical;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 特殊物资统计
 * @author: 王强
 * @create: 2022-08-22 17:58
 **/
@Controller
@RequestMapping(value = "${adminPath}/cg/reservemanagementcenter/specialSupply")
public class SpecialSupplyController extends BaseController {

    @Autowired
    private SpecialSupplyService supplyService;

    @Autowired
    private BudgetStatsService budgetStatsService;


    @ModelAttribute
    public SpecialSupply get(@RequestParam(required = false) String id) {
        SpecialSupply entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = supplyService.get(id);
        }
        if (entity == null) {
            entity = new SpecialSupply();
        }
        return entity;
    }

    /**
     * 特殊物资统计表页面
     * @param specialSupply
     * @param model
     * @return
     */
    @RequiresPermissions("cg:reservemanagementcenter:specialSupply:list")
    @RequestMapping(value = "supplyList")
    public String supplyList(SpecialSupply specialSupply, Model model) {
        model.addAttribute("specialSupply", specialSupply);
        return "modules/cg/statisticalTable/specialSupply/specialSupply";
    }

    /**
     * 特殊物资统计数据列表
     * @param specialSupply
     * @param request
     * @param response
     * @param model
     * @return
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialSupply:list")
    @RequestMapping(value = "list")
    public Map<String, Object> basicData(SpecialSupply specialSupply, HttpServletRequest request, HttpServletResponse response, Model model) {

        Page<SpecialSupply> page = supplyService.findPage(new Page<SpecialSupply>(request, response), specialSupply);
        List<SpecialSupply> list = page.getList();
        List<SpecialSupply> supplyList = new ArrayList<>();
        SpecialSupply supply = null;
        for (int i=0;i<list.size();i++){
            supply = list.get(i);
            //进行赋值操作
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = supplyService.getByProjectReserveId(supply.getProjectReserveId());
            //设置储备进度
            supply.setReserveProgress(budgetStatsService.getReserveProgress(supply.getProjectReserveId()));

            double kgg1 = 0.0;
            double kgg2 = 0.0;
            double kgg3 = 0.0;
            double kgg4 = 0.0;
            double kgg5 = 0.0;
            double kgg6 = 0.0;
            double kgg7 = 0.0;
            double kgg8 = 0.0;

            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = supplyService.getByProjectName(supply.getProjectName());
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500116761") &
                            dataList.get(j).getExtendDescription().equals("环网柜,AC10kV,630A,负荷开关柜,SF6,户内。SF6灭弧,带避雷器,电动,端子排")){
                        kgg1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500116761") &
                            dataList.get(j).getExtendDescription().equals("环网柜,AC10kV,630A,负荷开关柜,SF6,户内。SF6灭弧,不带避雷器,电动,端子排")){
                        kgg2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006630")){
                        kgg3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006556")){
                        kgg4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006703")){
                        kgg5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107555")){
                        kgg6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107558")){
                        kgg7 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107562")){
                        kgg8 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                }
            }
            //设置20kv物资统计
            supply.setMaterialStatisticA("");
            supply.setMaterialStatisticB("");
            supply.setMaterialStatisticC("");
            supply.setMaterialStatisticD("");
            //设置高低压开关柜统计
            supply.setSwitchCabinet10KV(doubleToString(kgg1));
            supply.setSwitchCabinet10KV02(doubleToString(kgg2));
            supply.setSwitchCabinetIncomeLine(doubleToString(kgg3));
            supply.setSwitchCabinetSegment(doubleToString(kgg4));
            supply.setSwitchCabinetFeeder(doubleToString(kgg5));
            supply.setNumberOfBranchBoxFourWay(doubleToString(kgg6));
            supply.setNumberOfBranchBoxFiveWay(doubleToString(kgg7));
            supply.setNumberOfBranchBoxSevenWay(doubleToString(kgg8));
            //设置低压分支箱路上统计
            //设置箱变路数统计
            supply.setNumberOfBox("");
            //设置特殊尺寸物资统计

            supplyList.add(supply);
        }
        page.setList(supplyList);
        return getBootstrapData(page);
    }

    /**
     *  导入Excel数据
     */
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialSupply:import")
    @RequestMapping(value = "import")
    public AjaxJson importBasic(@RequestParam("file") MultipartFile file, HttpServletResponse response, HttpServletRequest request) {
        AjaxJson j = new AjaxJson();
        try {
            ImportUtil importUtil = new ImportUtil(file, 0, 0);
            //从数据库中查出所有的 项目储备编号
            List<String> proIdList = supplyService.getAllProId();
            //获取导入表格所有数据
            List<SpecialSupply> specialSupplies = ExcelImportUtil.getSpecialUtil(importUtil,proIdList);
            supplyService.insertList(specialSupplies);
        } catch (Exception e) {
            j.setSuccess(false);
            j.setMsg("导入储备项目概预算信息失败！失败信息：" + e.getMessage());
        }
        return j;
    }

    /**
     * 删除表单
     */
    @ResponseBody
    @RequiresPermissions(value={"cg:reservemanagementcenter:specialSupply:del"},logical= Logical.OR)
    @RequestMapping(value = "deleteAll")
    public AjaxJson delete(String ids){
        AjaxJson j = new AjaxJson();
        String idArray[] =ids.split(",");
        for(String id : idArray){
            supplyService.deleteByProId(supplyService.get(id).getProjectReserveId());
        }
        j.setMsg("删除特殊物资统计表信息成功");
        return j;
    }

    //导出excel
    @ResponseBody
    @RequiresPermissions("cg:reservemanagementcenter:specialSupply:export")
    @RequestMapping(value = "export")
    public void exportExcel(SpecialSupply specialSupply, HttpServletRequest request, HttpServletResponse response) {
        List<SpecialSupply> list = supplyService.exportFindList(specialSupply);

        List<SpecialSupply> supplyList = new ArrayList<>();
        SpecialSupply supply = null;
        for (int i=0;i<list.size();i++){
            supply = list.get(i);
            //进行赋值操作
            //根据projectReserveId查出流程表的proc_ins_id
            String procInsId = supplyService.getByProjectReserveId(supply.getProjectReserveId());
            //设置储备进度
            supply.setReserveProgress(budgetStatsService.getReserveProgress(supply.getProjectReserveId()));

            double kgg1 = 0.0;
            double kgg2 = 0.0;
            double kgg3 = 0.0;
            double kgg4 = 0.0;
            double kgg5 = 0.0;
            double kgg6 = 0.0;
            double kgg7 = 0.0;
            double kgg8 = 0.0;

            //根据物料编码 和 物料描述从cg_material_data表中获取相应的数据
            List<MaterialData> dataList = supplyService.getByProjectName(supply.getProjectName());
            if (dataList.size()>0){
                for (int j=0;j<dataList.size();j++){
                    if (dataList.get(j).getMaterialCode().equals("500116761") &
                            dataList.get(j).getExtendDescription().equals("环网柜,AC10kV,630A,负荷开关柜,SF6,户内。SF6灭弧,带避雷器,电动,端子排")){
                        kgg1 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500116761") &
                            dataList.get(j).getExtendDescription().equals("环网柜,AC10kV,630A,负荷开关柜,SF6,户内。SF6灭弧,不带避雷器,电动,端子排")){
                        kgg2 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006630")){
                        kgg3 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006556")){
                        kgg4 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500006703")){
                        kgg5 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107555")){
                        kgg6 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107558")){
                        kgg7 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                    if (dataList.get(j).getMaterialCode().equals("500107562")){
                        kgg8 += Double.parseDouble(dataList.get(j).getTotalCount());
                    }
                }
            }
            //设置20kv物资统计
            supply.setMaterialStatisticA("");
            supply.setMaterialStatisticB("");
            supply.setMaterialStatisticC("");
            supply.setMaterialStatisticD("");
            //设置高低压开关柜统计
            supply.setSwitchCabinet10KV(doubleToString(kgg1));
            supply.setSwitchCabinet10KV02(doubleToString(kgg2));
            supply.setSwitchCabinetIncomeLine(doubleToString(kgg3));
            supply.setSwitchCabinetSegment(doubleToString(kgg4));
            supply.setSwitchCabinetFeeder(doubleToString(kgg5));
            supply.setNumberOfBranchBoxFourWay(doubleToString(kgg6));
            supply.setNumberOfBranchBoxFiveWay(doubleToString(kgg7));
            supply.setNumberOfBranchBoxSevenWay(doubleToString(kgg8));
            //设置低压分支箱路上统计
            //设置箱变路数统计
            supply.setNumberOfBox("");
            //设置特殊尺寸物资统计

            supplyList.add(supply);
        }

        //生成序列号
        int i = 1;
        for (SpecialSupply s : supplyList) {
            s.setId(String.valueOf(i));
            i++;
        }

        ExcelExportUtil util = ExcelExportUtil.getOne();
        XSSFWorkbook workbook = util.getWorkbook("specialSupply");
        util.exportSpecialSupply(response,workbook,supplyList);
    }

    public String doubleToString(Double value){
        if (value == 0.0){
            return "";
        }else {
            return value + "";
        }
    }
}
